@@ -4,11 +4,11 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Carp       ();
 use File::Temp ();
-use Future;
+use Future 0.40;
 use Proc::Background 1.30;
 use Scalar::Util ();
 
@@ -202,7 +202,7 @@ Git::Background - use Git commands with L<Future>
 
 =head1 VERSION
 
-Version 0.002
+Version 0.003
 
 =head1 SYNOPSIS
 
